import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Scanner;
import java.util.Properties;

class Conexao {
	// Design Pattern - Singleton
	private static Connection conn = null;

	public static Connection getConexao(String url, String user, String pass) throws SQLException{
		if((conn == null) || (conn.isClosed())) {
			conn = fabricaDeConexoes(url, user, pass);
		}
		
		return conn;
	}
		
	// Fábrica de Conexões
	public static Connection fabricaDeConexoes(String url, String user, String pass) {
		try{
			Class.forName("org.postgresql.Driver");
			
			Properties prop = new Properties();
			prop.put("user",user);
			prop.put("password", pass);
			prop.put("charset", "UTF-8");
			prop.put("lc_ctype", "ISO8859_1");
			
			return DriverManager.getConnection(url, prop);
		}
		catch(Exception e){
			System.err.println("Erro: " + e.getMessage());
		}
		
		return null;
	}
}

public class TesteConexao {
	public static void main(String[] args) {
		// PostgreSQL a porta padrão é 5432
		String url = "jdbc:postgresql://localhost:5433/Teste";
		String user = "postgres";
		String snh = "123456";
		Connection con = null;
		PreparedStatement pst = null,
				          pst2 = null;
		ResultSet rs = null;
		int codigo, resp;
		Scanner sc;

		try{
			Class.forName("org.postgresql.Driver");
			
			con = Conexao.getConexao(url, user, snh);
						
			int op, cod;
			String nome;
			
			sc = new Scanner(System.in);
			
			do{
				System.out.println("--==[Cadastro Pessoas]==--");
				System.out.println("1 - inserir");
				System.out.println("2 - alterar");
				System.out.println("3 - excluir");
				System.out.println("4 - cosultar");
				System.out.println("5 - relatório");
				System.out.println("6 - sair");
				System.out.println("Opção: ");
				op = sc.nextInt();
				
				switch(op){
				    case 1:
				    	System.out.println("-=[Inserção]=-");
				    	System.out.println("Código: ");
				    	cod = sc.nextInt();
				    	sc.nextLine();
				    	System.out.println("Nome: ");
				    	nome = sc.nextLine();
				    	
						pst = con.prepareStatement("insert into \"Pessoa\" (\"codigo\",\"nome\") values(?,?)");
						
						pst.setInt(1, cod);
						pst.setString(2, nome);
						
						pst.executeUpdate();
						pst.close();
				    	break;
				    case 2:
				    	System.out.println("-=[Alterar]=-");
				    	System.out.println("Digite o código: ");
				    	codigo = sc.nextInt();
				    	
				    	pst = con.prepareStatement(
				    			"select * " +
                                "  from \"Pessoa\" " +
                                " where codigo = ?",
				    			ResultSet.TYPE_SCROLL_INSENSITIVE,
			                    ResultSet.CONCUR_READ_ONLY);
				    	pst.setInt(1, codigo);
				    	
				    	rs = pst.executeQuery();
				    	if(rs.first()){
				    		System.out.println("-=[Pessoa Encontrada]=-");
				    		System.out.println("1 - Código: " + rs.getInt(1));
				    		System.out.println("2 - Nome  : " + rs.getString(2));

				    		int campo = 0;
				    		do{
					    		System.out.println("Qual campo deseja alterar?");
					    		campo = sc.nextInt();
					    		
					    		if(campo < 1 || campo > 2)
					    			System.out.println("Número do campo inválido!");
				    		}while(campo < 1 || campo > 2);
				    		
				    		switch(campo){
				    			case 1:
				    				System.out.println("Digite o novo código: ");
				    				int novoCodigo = sc.nextInt();
						    		pst2 = con.prepareStatement("update \"Pessoa\" " +
				    				                            "   set codigo = ? " +
						    			                        " where codigo = ?");
						    		pst2.setInt(1, novoCodigo);
						    		pst2.setInt(2, codigo);
						    		
						    		pst2.executeUpdate();
				    				break;
				    			case 2:
				    				System.out.println("Digite o novo nome: ");
				    				sc.nextLine();
				    				String novoNome = sc.nextLine();
						    		
				    				pst2 = con.prepareStatement("update \"Pessoa\" " +
                                                                "   set nome = ? " +
		                                                        " where codigo = ?");
						    		pst2.setString(1, novoNome);
						    		pst2.setInt(2, codigo);

						    		pst2.executeUpdate();
				    		}
				    		pst2.close();
				    	}
				    	else{
				    		System.out.println("Código inexistente.");
				    	}
			    		pst.close();
				    	rs.close();
				    	
				    	break;
				    case 3:
				    	System.out.println("-=[Excluir]=-");
				    	System.out.println("Digite o código: ");
				    	codigo = sc.nextInt();
				    	
				    	pst = con.prepareStatement(
				    			"select * " +
                                "  from \"Pessoa\" " +
                                " where codigo = ?",
				    			ResultSet.TYPE_SCROLL_INSENSITIVE,
			                    ResultSet.CONCUR_READ_ONLY);
				    	pst.setInt(1, codigo);
				    	
				    	rs = pst.executeQuery();
				    	if(rs.first()){
				    		System.out.println("-=[Pessoa Encontrada]=-");
				    		System.out.println("Código: " + rs.getInt(1));
				    		System.out.println("Nome  : " + rs.getString(2));

				    		System.out.println("Confirma exclusão? (1-sim/2-não)");
				    		resp = sc.nextInt();
				    		
				    		if(resp == 1){
				    			pst2 = con.prepareStatement("delete " +
				    		                                "  from \"Pessoa\" " +
				    				                        " where codigo = ?");
				    			
				    			pst2.setInt(1, codigo);
				    			
				    			pst2.executeUpdate();
				    		}
				    		else{
				    			System.out.println("Exclusão não efetuada.");
				    		}
				    		
				    		pst2.close();
				    	}
				    	else{
				    		System.out.println("Código inexistente.");
				    	}

			    		pst.close();
				    	rs.close();
				    	break;
				    case 4:
				    	System.out.println("-=[Consultar]=-");
				    	System.out.println("Digite o código: ");
				    	codigo = sc.nextInt();
				    	
				    	pst = con.prepareStatement(
				    			"select * " +
                                "  from \"Pessoa\" " +
                                " where codigo = ?",
				    			ResultSet.TYPE_SCROLL_INSENSITIVE,
			                    ResultSet.CONCUR_READ_ONLY);
				    	pst.setInt(1, codigo);
				    	
				    	rs = pst.executeQuery();
				    	if(rs.first()){
				    		System.out.println("-=[Pessoa Encontrada]=-");
				    		System.out.println("Código: " + rs.getInt(1));
				    		System.out.println("Nome  : " + rs.getString(2));
				    	}
				    	else{
				    		System.out.println("Código inexistente.");
				    	}

			    		pst.close();
				    	rs.close();
				    	break;
				    case 5:
				    	System.out.println("-=[Relatório]=-");
				    	
				    	pst = con.prepareStatement(
				    			"select * " +
                                "  from \"Pessoa\" ",
				    			ResultSet.TYPE_SCROLL_INSENSITIVE,
			                    ResultSet.CONCUR_READ_ONLY);
				    	
				    	rs = pst.executeQuery();
			    		System.out.println("-=[Pessoas Encontradas]=-");
				    	while(rs.next()){
				    		System.out.println("-----------------------");
				    		System.out.println("Código: " + rs.getInt(1));
				    		System.out.println("Nome  : " + rs.getString(2));
				    	}
			    		System.out.println("-----------------------");

			    		pst.close();
				    	rs.close();
				    	break;
				}
			}while(op != 6);
			con.close();
		}
		catch(SQLException | ClassNotFoundException e){
			System.out.println("Exceção: " + e.getMessage());
		}
	}
}
